summaryrefslogtreecommitdiffstats
path: root/ktouch/src/ktouchkeyboard.h
diff options
context:
space:
mode:
Diffstat (limited to 'ktouch/src/ktouchkeyboard.h')
-rw-r--r--ktouch/src/ktouchkeyboard.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/ktouch/src/ktouchkeyboard.h b/ktouch/src/ktouchkeyboard.h
index 5334c49b..0e2ebfd6 100644
--- a/ktouch/src/ktouchkeyboard.h
+++ b/ktouch/src/ktouchkeyboard.h
@@ -24,7 +24,7 @@
class KURL;
/// This class stores the keyboard layout and the connectivity between characters
/// and the actual keys.
class KTouchKeyboard {
public:
@@ -32,7 +32,7 @@ class KTouchKeyboard {
KTouchKeyboard() { createDefault(); }
/// Clears the keyboard (resets all data)
void clear();
/// Loads a keyboard layout (old format) from file (returns true if successful).
bool load(TQWidget * window, const KURL& url);
/// Loads a lecture (in XML format) from file (returns true if successful).
bool loadXML(TQWidget * window, const KURL& url);
@@ -46,10 +46,10 @@ class KTouchKeyboard {
TQValueVector<KTouchKey> m_keys; ///< Vector with key definitions.
TQValueVector<KTouchKeyConnector> m_connectors; ///< Vector with connectivity data.
- QString m_title; ///< Title of the keyboard (to appear in the menu).
- QString m_comment; ///< Comments about the creator of the keyboard layout.
- QString m_language; ///< Language ID of keyboard
- QString m_fontSuggestions; ///< Suggestions of fonts to be used on the keys.
+ TQString m_title; ///< Title of the keyboard (to appear in the menu).
+ TQString m_comment; ///< Comments about the creator of the keyboard tqlayout.
+ TQString m_language; ///< Language ID of keyboard
+ TQString m_fontSuggestions; ///< Suggestions of fonts to be used on the keys.
// These variables are recalculated after the keyboard was loaded.
int m_width; ///< The width of the keyboard (maximum of the sums of all keywidths in each line).
@@ -24,7 +24,7 @@
class KURL;
-/// This class stores the keyboard layout and the connectivity between characters
+/// This class stores the keyboard tqlayout and the connectivity between characters
/// and the actual keys.
class KTouchKeyboard {
@@ -32,7 +32,7 @@ class KTouchKeyboard {
/// Clears the keyboard (resets all data)
void clear();
- /// Loads a keyboard layout (old format) from file (returns true if successful).
+ /// Loads a keyboard tqlayout (old format) from file (returns true if successful).
bool load(TQWidget * window, const KURL& url);
/// Loads a lecture (in XML format) from file (returns true if successful).